@@ -6,6 +6,11 @@ from apicase.schema import BaseModel
 from apicase.client.router import APIRouter
 from apicase.client.reuquest import session
 from apicase.assertion import JSONAsserter
-from apicase.common.enumeration import BodyTypeEnum
+from apicase.common.enumeration import (
+    BodyTypeEnum,
+)
+from apicase.common.schema import (
+    RequestSchema,
+)
 
 bt = BodyTypeEnum
